==> cmake-2.8.3p3.tgz: share/cmake/Modules/FindMPEG.cmake <==
# - Find the native MPEG includes and library
# This module defines
#  MPEG_INCLUDE_DIR, where to find MPEG.h, etc.
#  MPEG_LIBRARIES, the libraries required to use MPEG.
#  MPEG_FOUND, If false, do not try to use MPEG.
# also defined, but not for general use are
#  MPEG_mpeg2_LIBRARY, where to find the MPEG library.
#  MPEG_vo_LIBRARY, where to find the vo library.

#=============================================================================
# Copyright 2002-2009 Kitware, Inc.
#
# Distributed under the OSI-approved BSD License (the "License");
# see accompanying file Copyright.txt for details.
#
# This software is distributed WITHOUT ANY WARRANTY; without even the
# implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the License for more information.
#=============================================================================
# (To distribute this file outside of CMake, substitute the full
#  License text for the above reference.)

FIND_PATH(MPEG_INCLUDE_DIR mpeg2dec/mpeg2.h
  /usr/local/include
)

FIND_LIBRARY(MPEG_mpeg2_LIBRARY mpeg2
  /usr/local/lib
)

# handle the QUIETLY and REQUIRED arguments and set MPEG2_FOUND to TRUE if 
# all listed variables are TRUE
INCLUDE("${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake")
FIND_PACKAGE_HANDLE_STANDARD_ARGS(MPEG DEFAULT_MSG MPEG_INCLUDE_DIR MPEG_mpeg2_LIBRARY)

IF(MPEG_FOUND)
  SET( MPEG_LIBRARIES ${MPEG_mpeg2_LIBRARY} )
ENDIF(MPEG_FOUND)

MARK_AS_ADVANCED(MPEG_INCLUDE_DIR MPEG_mpeg2_LIBRARY)

==> cmake-2.8.8p9.tgz: share/cmake/Modules/FindMPEG.cmake <==
# - Find the native MPEG includes and library
# This module defines
#  MPEG_INCLUDE_DIR, where to find MPEG.h, etc.
#  MPEG_LIBRARIES, the libraries required to use MPEG.
#  MPEG_FOUND, If false, do not try to use MPEG.
# also defined, but not for general use are
#  MPEG_mpeg2_LIBRARY, where to find the MPEG library.
#  MPEG_vo_LIBRARY, where to find the vo library.

#=============================================================================
# Copyright 2002-2009 Kitware, Inc.
#
# Distributed under the OSI-approved BSD License (the "License");
# see accompanying file Copyright.txt for details.
#
# This software is distributed WITHOUT ANY WARRANTY; without even the
# implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the License for more information.
#=============================================================================
# (To distribute this file outside of CMake, substitute the full
#  License text for the above reference.)

FIND_PATH(MPEG_INCLUDE_DIR mpeg2dec/mpeg2.h
  /usr/local/include
)

FIND_LIBRARY(MPEG_mpeg2_LIBRARY mpeg2
  /usr/local/lib
)

# handle the QUIETLY and REQUIRED arguments and set MPEG2_FOUND to TRUE if 
# all listed variables are TRUE
INCLUDE(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(MPEG DEFAULT_MSG MPEG_INCLUDE_DIR MPEG_mpeg2_LIBRARY)

IF(MPEG_FOUND)
  SET( MPEG_LIBRARIES ${MPEG_mpeg2_LIBRARY} )
ENDIF(MPEG_FOUND)

MARK_AS_ADVANCED(MPEG_INCLUDE_DIR MPEG_mpeg2_LIBRARY)
